==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algeline/mlnfld.f <==
      SUBROUTINE MLNFLD(N,FRONTL,FRONTU,ADPER,T1,T2,AD,EPS,IER)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGELINE  DATE 04/05/2004   AUTEUR ROSE C.ROSE 
C RESPONSABLE ROSE C.ROSE
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER N,ADPER(*),AD(*),IER
      REAL*8 FRONTL(*),T1(*),FRONTU(*),T2(*),EPS
      INTEGER  I,K
      INTEGER SEUIN,SEUIK
      PARAMETER(SEUIN=1500,SEUIK=300)
      INTEGER NN,KK,LDA
C     VERSION AVEC APPEL A DGEMV POUR LES PRODUITS MATRICE-VECTEUR
C     AU DELA D' UN CERTAIN SEUIL
C     DGEMV EST APPEL A TRAVERS LA FONCTION C DGEMW POUR CAR DGEMV
C     NECESSITE DES ARGUMENTS ENTIER INTEGER*4 REFUSES PAR ASTER
C     MLTFLD TRAITE UNIQUEMENT LES BLOCS DIAGONAUX
      LDA = N
      DO 30 K = 1,N
        DO 10 I = 1,K - 1
          AD(I) = ADPER(I) + K - I        
          T1(I) = FRONTU(AD(I))
          T2(I) = FRONTL(AD(I))
   10   CONTINUE
        IF (K.GT.1) THEN
C
           NN= N-K+1
           KK= K-1
           IF(NN.LT.SEUIN.OR.KK.LT.SEUIK) THEN
          CALL SSPMVA(N-K+1,K-1,FRONTL,AD,T1,FRONTL(ADPER(K)))
          CALL SSPMVA(N-K+1,K-1,FRONTU,AD,T2,FRONTU(ADPER(K)))
          ELSE
          CALL DGEMW(NN,KK,FRONTL(K),LDA,T1,FRONTL(ADPER(K)))
          CALL DGEMW(NN,KK,FRONTU(K),LDA,T2,FRONTU(ADPER(K)))
          ENDIF
       ENDIF
C         DIVISION PAR LE TERME DIAGONAL DE FRONTL (PAS FRONTU)
        IF (ABS(FRONTL(ADPER(K))).LE.EPS) THEN
          IER = K
          GO TO 40
        END IF
CRAY DIR$ IVDEP DIRECTIVE INHIBEE CAR DEPENDANCE AVANT
        DO 20 I = 1,N - K
          FRONTL(ADPER(K)+I) = FRONTL(ADPER(K)+I)/FRONTL(ADPER(K))
   20   CONTINUE
   30 CONTINUE
   40 CONTINUE
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algeline/mlnfld.f <==
      SUBROUTINE MLNFLD(N,FRONTL,FRONTU,ADPER,T1,T2,AD,EPS,IER)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGELINE  DATE 31/01/2005   AUTEUR REZETTE C.REZETTE 
C RESPONSABLE ROSE C.ROSE
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER N,ADPER(*),AD(*),IER
      REAL*8 FRONTL(*),T1(*),FRONTU(*),T2(*),EPS,ALPHA,BETA
      INTEGER  I,K
      INTEGER SEUIN,SEUIK
      PARAMETER(SEUIN=1500,SEUIK=300)
      INTEGER NN,KK,LDA,INCX,INCY
      CHARACTER*1 TRA
      TRA='N'
      ALPHA=-1.D0
      BETA=1.D0
      INCX=1
      INCY=1
      LDA = N
      DO 30 K = 1,N
        DO 10 I = 1,K - 1
          AD(I) = ADPER(I) + K - I        
          T1(I) = FRONTU(AD(I))
          T2(I) = FRONTL(AD(I))
   10   CONTINUE
        IF (K.GT.1) THEN
C
           NN= N-K+1
           KK= K-1
           IF(NN.LT.SEUIN.OR.KK.LT.SEUIK) THEN
          CALL SSPMVA(N-K+1,K-1,FRONTL,AD,T1,FRONTL(ADPER(K)))
          CALL SSPMVA(N-K+1,K-1,FRONTU,AD,T2,FRONTU(ADPER(K)))
          ELSE
          CALL DGEMV(TRA,NN,KK,ALPHA,FRONTL(K),LDA,T1,INCX,BETA,
     &               FRONTL(ADPER(K)),INCY)
          CALL DGEMV(TRA,NN,KK,ALPHA,FRONTU(K),LDA,T2,INCX,BETA,
     &               FRONTU(ADPER(K)),INCY)
          ENDIF
       ENDIF
C         DIVISION PAR LE TERME DIAGONAL DE FRONTL (PAS FRONTU)
        IF (ABS(FRONTL(ADPER(K))).LE.EPS) THEN
          IER = K
          GO TO 40
        END IF
CRAY DIR$ IVDEP DIRECTIVE INHIBEE CAR DEPENDANCE AVANT
        DO 20 I = 1,N - K
          FRONTL(ADPER(K)+I) = FRONTL(ADPER(K)+I)/FRONTL(ADPER(K))
   20   CONTINUE
   30 CONTINUE
   40 CONTINUE
      END
